@@ -3,7 +3,7 @@
  * logtofile_guc.c
  *      GUC variables for logtofile
  *
- * Copyright (c) 2020-2024, Francisco Miguel Biete Banon
+ * Copyright (c) 2020-2025, Francisco Miguel Biete Banon
  *
  * This code is released under the PostgreSQL licence, as given at
  *  http://www.postgresql.org/about/licence/
@@ -33,3 +33,32 @@ bool guc_check_directory(char **newval, void **extra, GucSource source)
   canonicalize_path(*newval);
   return true;
 }
+
+/**
+ * @brief GUC Callback pgaudit.log_format check value (csv or json)
+ * @param newval: new value
+ * @param extra: extra
+ * @param source: source
+ * @return bool: true if value is csv or json
+ */
+bool guc_check_log_format(char **newval, void **extra, GucSource source)
+{
+  char *rawstring;
+
+  rawstring = pstrdup(*newval);
+
+  if (pg_strcasecmp(rawstring, "csv") == 0)
+  {
+    pfree(rawstring);
+    return true;
+  }
+
+  if (pg_strcasecmp(rawstring, "json") == 0)
+  {
+    pfree(rawstring);
+    return true;
+  }
+
+  pfree(rawstring);
+  return false;
+}
\ No newline at end of file
